@@ -3,7 +3,7 @@
 <node TEXT="Latest Freeplane features" STYLE_REF="Introduction" FOLDED="false" ID="ID_1286342769" BACKGROUND_COLOR="#99ccff" MIN_WIDTH="0 cm" VGAP_QUANTITY="2 pt">
 <edge DASH="SOLID"/>
 <hook NAME="MapStyle" background="#ffccccff">
-    <properties show_icon_for_attributes="false" show_notes_in_map="false" show_note_icons="true" fit_to_viewport="false;" show_tags="UNDER_NODES"/>
+    <properties show_icon_for_attributes="false" show_notes_in_map="false" auto_compact_layout="true" show_tags="UNDER_NODES" show_note_icons="true" fit_to_viewport="false;" show_icons="BESIDE_NODES" showTagCategories="false"/>
     <tags category_separator="::"/>
 
 <map_styles>
@@ -74,6 +74,11 @@
 </map_styles>
 </hook>
 <node TEXT="Version 1.12.x" POSITION="bottom_or_right" ID="ID_585965147">
+<node TEXT="Version 1.12.11" ID="ID_695231532">
+<node TEXT="Editor features" ID="ID_1804949975">
+<node TEXT="Automatic compact layout" ID="ID_767781867"/>
+</node>
+</node>
 <node TEXT="Version 1.12.2" ID="ID_1654459656">
 <node TEXT="Editor features" ID="ID_159604560">
 <node TEXT="Node tags" ID="ID_886055435" LINK="freeplaneUserGuide.mm#ID_889515076"/>
@@ -87,9 +92,9 @@
 </node>
 </node>
 </node>
-<node TEXT="Version 1.11.x" STYLE_REF="Actions" FOLDED="true" POSITION="bottom_or_right" ID="ID_414352132">
+<node TEXT="Version 1.11.x" STYLE_REF="Actions" POSITION="bottom_or_right" ID="ID_414352132">
 <node TEXT="Version 1.11.11" FOLDED="true" ID="ID_1996460640">
-<node TEXT="Editor features" FOLDED="true" ID="ID_960043093">
+<node TEXT="Editor features" ID="ID_960043093">
 <node TEXT="Record and analyze violations found by ArchUnit tests" ID="ID_237251897" LINK="https://github.com/freeplane/freeplane-archunit-extension"/>
 <node TEXT="Save user defined attributes and details on code explorer nodes" ID="ID_472050454"/>
 <node TEXT="Use Operating System Regional Settings by default" ID="ID_109457892"/>
@@ -97,7 +102,7 @@
 </node>
 </node>
 <node TEXT="Version 1.11.9" STYLE_REF="Actions" FOLDED="true" ID="ID_289590210">
-<node TEXT="Editor features" STYLE_REF="Purpose" FOLDED="true" ID="ID_1031432368">
+<node TEXT="Editor features" STYLE_REF="Purpose" ID="ID_1031432368">
 <node TEXT="Navigate-&gt;Auto-expand selected nodes" ID="ID_1906031168"/>
 <node TEXT="JVM Code Explorer mode (based on ArchUnit)" ID="ID_604199270" LINK="https://www.freeplane.org/codeexplorer-video"/>
 </node>
